@@ -178,6 +178,8 @@ seahorse_passphrase_prompt_show (const gchar *title, const gchar *description,
         prompt = _("Password:"); 
     
     w = gtk_dialog_new_with_buttons (title, NULL, GTK_DIALOG_NO_SEPARATOR, NULL);
+    gtk_window_set_icon_name (GTK_WINDOW (w), GTK_STOCK_DIALOG_AUTHENTICATION);
+
     dialog = GTK_DIALOG (w);
 
     g_signal_connect (G_OBJECT (dialog), "size-request",
@@ -547,7 +549,7 @@ ssh_detect_agent ()
     memset (&sunaddr, 0, sizeof (sunaddr));
     sunaddr.sun_family = AF_UNIX;
     g_strlcpy (sunaddr.sun_path, socketpath, sizeof (sunaddr.sun_path));
-    if (connect (agentfd, (struct sockaddr*) &sunaddr, sizeof sunaddr) < 0) {
+    if (connect (agentfd, (struct sockaddr*) &sunaddr, sizeof (sunaddr)) < 0) {
         g_warning ("couldn't connect to SSH agent at: %s: %s", socketpath, 
                    g_strerror (errno));
         close (agentfd);
