@@ -20,7 +20,7 @@
  */
 
 #include <stdlib.h>
-#include <libintl.h>
+#include <config.h>
 #include <gnome.h>
 
 #include "seahorse-operation.h"
@@ -28,8 +28,7 @@
 #include "seahorse-libdialogs.h"
 #include "seahorse-widget.h"
 #include "seahorse-validity.h"
-#include "seahorse-recipients-store.h"
-#include "seahorse-default-key-control.h"
+#include "seahorse-combo-keys.h"
 #include "seahorse-gconf.h"
 #include "seahorse-pgp-key.h"
 #include "seahorse-util.h"
@@ -77,12 +76,12 @@ seahorse_signer_get ()
             
     combo = glade_xml_get_widget (swidget->xml, "signer-select");
     g_return_val_if_fail (combo != NULL, NULL);
-    seahorse_combo_keys_attach (GTK_OPTION_MENU (combo), skset, NULL);
+    seahorse_combo_keys_attach (GTK_COMBO_BOX (combo), skset, NULL);
     g_object_unref (skset);
     
     /* Select the last key used */
-    id = seahorse_gconf_get_string (LASTSIGNER_KEY);
-    seahorse_combo_keys_set_active_id (GTK_OPTION_MENU (combo), id);
+    id = seahorse_gconf_get_string (SEAHORSE_LASTSIGNER_KEY);
+    seahorse_combo_keys_set_active_id (GTK_COMBO_BOX (combo), g_quark_from_string (id));
     g_free (id); 
     
     widget = seahorse_widget_get_top (swidget);
@@ -102,12 +101,12 @@ seahorse_signer_get ()
     }
 
     if (ok) {
-        skey = seahorse_combo_keys_get_active (GTK_OPTION_MENU (combo));
+        skey = seahorse_combo_keys_get_active (GTK_COMBO_BOX (combo));
         g_return_val_if_fail (SEAHORSE_IS_PGP_KEY (skey), NULL);
 
         /* Save this as the last key signed with */
-        seahorse_gconf_set_string (LASTSIGNER_KEY, skey == NULL ? 
-                        "" : seahorse_key_get_keyid (skey));
+        seahorse_gconf_set_string (SEAHORSE_LASTSIGNER_KEY, skey == NULL ? 
+                        "" : g_quark_to_string (seahorse_key_get_keyid (skey)));
     }
     
     seahorse_widget_destroy (swidget);
