@@ -27,6 +27,7 @@
 #include <time.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <string.h>
 
 #include <gnome.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -157,19 +158,28 @@ seahorse_util_error_domain ()
  * @err  Resulting GError object
  **/
 void    
-seahorse_util_gpgme_to_error(gpgme_error_t gerr, GError** err)
+seahorse_util_gpgme_to_error (gpgme_error_t gerr, GError** err)
 {
+    gpgme_err_code_t code;
+    
     /* Make sure this is actually an error */
-    g_assert(!GPG_IS_OK(gerr));
-    g_set_error(err, SEAHORSE_GPGME_ERROR, gpgme_err_code(gerr), 
-                            "%s", gpgme_strerror(gerr));
+    g_assert (!GPG_IS_OK(gerr));
+    code = gpgme_err_code (gerr);
+    
+    /* Special case some error messages */
+    if (code == GPG_ERR_DECRYPT_FAILED) {
+        g_set_error (err, SEAHORSE_GPGME_ERROR, code, "%s", 
+                     _("Decryption failed. You probably do not have the decryption key."));
+    } else {
+        g_set_error (err, SEAHORSE_GPGME_ERROR, code, "%s", 
+                     gpgme_strerror (gerr));
+    }
 }
-
 /** 
  * seahorse_util_get_date_string:
  * @time: Time value to parse
  *
- * Creates a string representation of @time.
+ * Creates a string representation of @time for use with gpg.
  *
  * Returns: A string representing @time
  **/
@@ -179,6 +189,30 @@ seahorse_util_get_date_string (const time_t time)
 	GDate *created_date;
 	gchar *created_string;
 	
+	if (time == 0)
+		return "0";
+	
+	created_date = g_date_new ();
+	g_date_set_time (created_date, time);
+	created_string = g_new (gchar, 11);
+	g_date_strftime (created_string, 11, "%Y-%m-%d", created_date);
+	return created_string;
+}
+
+/** 
+ * seahorse_util_get_display_date_string:
+ * @time: Time value to parse
+ *
+ * Creates a string representation of @time for display in the UI.
+ *
+ * Returns: A string representing @time
+ **/
+gchar*
+seahorse_util_get_display_date_string (const time_t time)
+{
+	GDate *created_date;
+	gchar *created_string;
+	
 	if (time == 0)
 		return "0";
 	
@@ -726,7 +760,9 @@ seahorse_util_detect_mime_type (const gchar *mime)
         return SKEY_PGP;
     
 #ifdef WITH_SSH 
-    else if (g_ascii_strcasecmp (mime, "application/x-ssh-key") == 0)
+    /* TODO: For now all PEM keys are treated as SSH keys */
+    else if (g_ascii_strcasecmp (mime, "application/x-ssh-key") == 0 ||
+             g_ascii_strcasecmp (mime, "application/x-pem-key") == 0)
         return SKEY_SSH;
 #endif 
     
@@ -811,7 +847,11 @@ seahorse_util_chooser_show_key_files (GtkWidget *dialog)
        cases that extension is associated with text/plain */
     gtk_file_filter_set_name (filter, _("All key files"));
     gtk_file_filter_add_mime_type (filter, "application/pgp-keys");
-    gtk_file_filter_add_pattern (filter, "*.asc");    
+#ifdef WITH_SSH 
+    gtk_file_filter_add_mime_type (filter, "application/x-ssh-key");
+    gtk_file_filter_add_mime_type (filter, "application/x-pem-key");
+#endif
+    gtk_file_filter_add_pattern (filter, "*.asc");
     gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);    
     gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
 
@@ -1175,7 +1215,7 @@ seahorse_util_string_up_first (const gchar *orig)
     /* Just use ASCII functions when not UTF8 */        
     } else {
         ret = g_strdup (orig);
-        g_ascii_toupper (ret[0]);
+        ret[0] = g_ascii_toupper (ret[0]);
     }
     
     return ret;
@@ -1223,6 +1263,49 @@ seahorse_util_string_slist_equal (GSList *l1, GSList *l2)
     return !l1 && !l2;   
 }
 
+gboolean 
+seahorse_util_string_is_whitespace (const gchar *text)
+{
+    g_assert (text);
+    g_assert (g_utf8_validate (text, -1, NULL));
+    
+    while (*text) {
+        if (!g_unichar_isspace (g_utf8_get_char (text)))
+            return FALSE;
+        text = g_utf8_next_char (text);
+    }
+    return TRUE;
+}
+
+void
+seahorse_util_string_trim_whitespace (gchar *text)
+{
+    gchar *b, *e, *n;
+    
+    g_assert (text);
+    g_assert (g_utf8_validate (text, -1, NULL));
+    
+    /* Trim the front */
+    b = text;
+    while (*b && g_unichar_isspace (g_utf8_get_char (b)))
+        b = g_utf8_next_char (b);
+    
+    /* Trim the end */
+    n = e = b + strlen (b);
+    while (n >= b) {
+        if (*n && !g_unichar_isspace (g_utf8_get_char (n)))
+            break;
+        e = n;
+        n = g_utf8_prev_char (e);
+    }
+    
+    g_assert (b >= text);
+    g_assert (e >= b);
+
+    *e = 0;
+    g_memmove (text, b, (e + 1) - b);
+}
+
 /* Callback to determine where a popup menu should be placed */
 void
 seahorse_util_determine_popup_menu_position (GtkMenu *menu, int *x, int *y,
